@@ -3,7 +3,7 @@ package Nile::HTTP::PSGI;
 use strict;
 use 5.008_001;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 use base qw(CGI::Simple);
 
@@ -156,7 +156,7 @@ for my $method (qw(
     remote_ident
     remote_user
     request_method
-    script_name
+    #script_name
     server_name
     server_port
     server_protocol
@@ -169,7 +169,7 @@ for my $method (qw(
     http
     https
     protocol
-    url
+    #url
 )) {
     no strict 'refs';
     *$method = sub {
@@ -180,6 +180,72 @@ for my $method (qw(
     };
 }
 
+sub script_name {
+	my ($self) = @_;
+	#$ENV{'SCRIPT_NAME'} || $0 || '' 
+	$self->env->{SCRIPT_NAME} || '' 
+}
+
+sub url {
+	my ( $self, @p ) = @_;
+	use CGI::Simple::Util 'rearrange';
+	my ( $relative, $absolute, $full, $path_info, $query, $base )
+	= rearrange(
+		[
+		  'RELATIVE', 'ABSOLUTE', 'FULL',
+		  [ 'PATH',  'PATH_INFO' ],
+		  [ 'QUERY', 'QUERY_STRING' ], 'BASE'
+		],
+		@p
+	);
+
+	my $url;
+
+	local *ENV = $self->{psgi_env};
+
+	$full++ if $base || !( $relative || $absolute );
+
+	my $path = $self->path_info;
+
+	my $script_name = $self->script_name;
+
+	if ($full) {
+		my $protocol = $self->protocol();
+		$url = "$protocol://";
+		my $vh = $self->http( 'host' );
+
+		if ($vh) {
+			$url .= $vh;
+		}
+		else {
+			$url .= server_name();
+			my $port = $self->server_port;
+			$url .= ":" . $port
+			unless ( lc( $protocol ) eq 'http' && $port == 80 )
+					or ( lc( $protocol ) eq 'https' && $port == 443 );
+		}
+
+		return $url if $base;
+		#$url .= $script_name;
+		#$url .= $path;
+	}
+	elsif ($relative) {
+		($url) = $script_name =~ m#([^/]+)$#;
+	}
+	elsif ($absolute) {
+		#$url = $script_name;
+		$url = $path;
+	}
+
+	$url .= $path if $path_info and defined $path;
+	$url .= "?" . $self->query_string if $query and $self->query_string;
+	$url = '' unless defined $url;
+
+	$url	=~ s/([^a-zA-Z0-9_.%;&?\/\\:+=~-])/uc sprintf("%%%02x",ord($1))/eg;
+
+	return $url;
+}
+
 sub DESTROY {
     my $self = shift;
     CGI::Simple::_initialize_globals();
